/*
	Copyright © 2003 RiskCare Ltd. All rights reserved.
	Copyright © 2010 SvgNet & SvgGdi Bridge Project. All rights reserved.
	Copyright © 2015 Rafael Teixeira, Mojmír Němeček, Benjamin Peterson and Other Contributors

	Original source code licensed with BSD-2-Clause spirit, treat it thus, see accompanied LICENSE for more
*/
using System;
using System.Collections;
using System.Xml;
using System.Text;
using System.IO;
using SvgNet.SvgTypes;

namespace SvgNet
{
	public class SvgFontElement : SvgElement
	{
		public SvgFontElement() {}
		public SvgFontElement(string id) : base(id)	{}

		private FontDefInfo info;

		public FontDefInfo Font 
		{
			get { return info; }
			set { info = value; }
		}
		
		public override void ReadXmlElement(XmlDocument doc, XmlElement el)	{ }

		public override void WriteXmlElements(XmlDocument doc, XmlElement parent)
		{
			XmlElement font = doc.CreateElement("font");
			//font.SetAttribute("horiz-adv-x", "" + info.advance); /* not configured and optional as evbery glyph has right one */
			font.SetAttribute("id", Id);

			XmlElement face = doc.CreateElement("font-face");
			face.SetAttribute("ascent",  "" + info.ascent);
			face.SetAttribute("font-style", info.style);
			face.SetAttribute("descent", "" + info.descent);
			face.SetAttribute("units-per-em", "" + info.units_per_em);
			face.SetAttribute("font-family", info.family);
			face.SetAttribute("font-weight", info.weight);
			font.AppendChild(face);
			
			XmlElement mg = doc.CreateElement("missing-glyph");
			mg.SetAttribute("horiz-adv-x", "" + info.missing_gly.advance);
			mg.SetAttribute("d", info.missing_gly.d);
			font.AppendChild(mg);

			foreach(var k in info.gly) {
				XmlElement g = doc.CreateElement("glyph");
				g.SetAttribute("unicode", "" + k.u);
				g.SetAttribute("horiz-adv-x", "" + k.advance);
				g.SetAttribute("d", k.d);
				font.AppendChild(g);
			}

			if(parent == null)
				doc.AppendChild(font);
			else
				parent.AppendChild(font);
			
			foreach(SvgElement el in _children)
			{
				el.WriteXmlElements(doc, font);
			}
		}
	}
}
